<!DOCTYPE html><htmllang="en"><head><metacharset="utf-8"><metaname="viewport"content="width=device-width, initial-scale=1.0"><metaname="generator"content="rustdoc"><metaname="description"content="For some reason, there seems to be no existing method to easily render fmt::Arguments in a pre-allocated byte array."><title>render_arguments in delog::render - Rust</title><script>if(window.location.protocol!=="file:")document.head.insertAdjacentHTML("beforeend","SourceSerif4-Regular-6b053e98.ttf.woff2,FiraSans-Italic-81dc35de.woff2,FiraSans-Regular-0fe48ade.woff2,FiraSans-MediumItalic-ccf7e434.woff2,FiraSans-Medium-e1aa3f0a.woff2,SourceCodePro-Regular-8badfe75.ttf.woff2,SourceCodePro-Semibold-aa29a496.ttf.woff2".split(",").map(f=>`<link rel="preload" as="font" type="font/woff2" crossorigin href="../../static.files/${f}">`).join(""))</script><linkrel="stylesheet"href="../../static.files/normalize-9960930a.css"><linkrel="stylesheet"href="../../static.files/rustdoc-84e720fa.css"><metaname="rustdoc-vars"data-root-path="../../"data-static-root-path="../../static.files/"data-current-crate="delog"data-themes=""data-resource-suffix=""data-rustdoc-version="1.89.0 (29483883e 2025-08-04)"data-channel="1.89.0"data-search-js="search-92309212.js"data-settings-js="settings-5514c975.js"><scriptsrc="../../static.files/storage-4e99c027.js"></script><scriptdefersrc="sidebar-items.js"></script><scriptdefersrc="../../static.files/main-fd3af306.js"></script><noscript><linkrel="stylesheet"href="../../static.files/noscript-32bb7600.css"></noscript><linkrel="alternate icon"type="image/png"href="../../static.files/favicon-32x32-6580c154.png"><linkrel="icon"type="image/svg+xml"href="../../static.files/favicon-044be391.svg"></head><bodyclass="rustdoc fn"><!--[if lte IE 11]><div class="warning">This old browser is unsupported and will most likely display funky things.</div><![endif]--><navclass="mobile-topbar"><buttonclass="sidebar-menu-toggle"title="show sidebar"></button></nav><navclass="sidebar"><divclass="sidebar-crate"><h2><ahref="../../delog/index.html">delog</a><spanclass="version">0.1.8</span></h2></div><divclass="sidebar-elems"><divid="rustdoc-modnav"><h2><ahref="index.html">In delog::<wbr>render</a></h2></div></div></nav><divclass="sidebar-resizer"title="Drag to resize sidebar"></div><main><divclass="width-limiter"><rustdoc-search></rustdoc-search><sectionid="main-content"class="content"><divclass="main-heading"><divclass="rustdoc-breadcrumbs"><ahref="../index.html">delog</a>::<wbr><ahref="index.html">render</a></div><h1>Function <spanclass="fn">render_arguments</span><buttonid="copy-path"title="Copy item path to clipboard">Copy item path</button></h1><rustdoc-toolbar></rustdoc-toolbar><spanclass="sub-heading"><aclass="src"href="../../src/delog/render.rs.html#9-15">Source</a></span></div><preclass="rust item-decl"><code>pub fn render_arguments<'a>(buf: &'a mut [<aclass="primitive"href="https://doc.rust-lang.org/1.89.0/core/primitive.u8.html">u8</a>], args: <aclass="struct"href="https://doc.rust-lang.org/1.89.0/core/fmt/struct.Arguments.html"title="struct core::fmt::Arguments">Arguments</a><'_>) ->&'a [<aclass="primitive"href="https://doc.rust-lang.org/1.89.0/core/primitive.u8.html">u8</a>]</code></pre><detailsclass="toggle top-doc"open><summaryclass="hideme"><span>Expand description</span></summary><divclass="docblock"><p>For some reason, there seems to be no existing method to easily render